@@ -1,9 +1,4 @@
-import sys
-
-if sys.version_info >= (3, 0):
-    from itertools import zip_longest
-else:
-    from itertools import izip_longest as zip_longest  # noqa
+from itertools import zip_longest
 
 
 def transposed(in_data):
